@@ -424,7 +424,7 @@ class SqlitePersonSession : Sqlite
 
 		//delete encoder signal and curves (and it's videos)
 		ArrayList encoderArray = SqliteEncoder.Select(true, -1, 
-				Convert.ToInt32(personID), Convert.ToInt32(sessionID), "signal", false);
+				Convert.ToInt32(personID), Convert.ToInt32(sessionID), "signal", false, true);
 		foreach(EncoderSQL eSQL in encoderArray) {
 			Util.FileDelete(eSQL.GetFullURL(false));	//signal, don't convertPathToR
 			if(eSQL.future2 != "")
@@ -432,7 +432,7 @@ class SqlitePersonSession : Sqlite
 			Sqlite.Delete(true, Constants.EncoderTable, Convert.ToInt32(eSQL.uniqueID));
 		}
 		encoderArray = SqliteEncoder.Select(true, -1, 
-				Convert.ToInt32(personID), Convert.ToInt32(sessionID), "curve", false);
+				Convert.ToInt32(personID), Convert.ToInt32(sessionID), "curve", false, true);
 		foreach(EncoderSQL eSQL in encoderArray) {
 			Util.FileDelete(eSQL.GetFullURL(false));	//don't convertPathToR
 			/* commented: curve has no video
@@ -440,6 +440,7 @@ class SqlitePersonSession : Sqlite
 				Util.FileDelete(eSQL.future2);
 			*/
 			Sqlite.Delete(true, Constants.EncoderTable, Convert.ToInt32(eSQL.uniqueID));
+			SqliteEncoder.DeleteSignalCurveWithCurveID(true, Convert.ToInt32(eSQL.uniqueID));
 		}
 				
 		
