@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2012   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -692,6 +692,19 @@ public class Util
 	public static bool IsEven(int myInt) {
 		return (myInt % 2 == 0); //check if it's even (in spanish "par")
 	}
+	
+	/********** start of LocalApplicationData path ************/
+	
+	//parent of database, multimedia and encoder
+	public static string GetParentDir() {
+		return Path.Combine(
+				Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData),
+				"Chronojump");
+	}
+	
+	/********** end of LocalApplicationData path ************/
+	
+	/********** start of database paths ************/
 
 	public static string GetReallyOldDatabaseDir() {
 		return Environment.GetEnvironmentVariable("HOME")+ Path.DirectorySeparatorChar + ".chronojump";
@@ -719,6 +732,7 @@ public class Util
 		return Path.Combine(Path.GetTempPath(), "Chronojump");
 	}
 
+	/********** end of database paths ************/
 	
 	/********** start of multimedia paths ************/
 
@@ -883,14 +897,26 @@ public class Util
 			Log.WriteLine("Error, chronojump.db file doesn't exist!");
 		}
 	}
-	
+
+	//http://stackoverflow.com/a/58779	
+	public static void CopyFilesRecursively(DirectoryInfo source, DirectoryInfo target) {
+		foreach (DirectoryInfo dir in source.GetDirectories())
+			CopyFilesRecursively(dir, target.CreateSubdirectory(dir.Name));
+		foreach (FileInfo file in source.GetFiles())
+			file.CopyTo(Path.Combine(target.FullName, file.Name));
+	}
+
 	public static bool FileDelete(string fileName) {
 		try {
 			if(File.Exists(fileName)) {
+				Log.WriteLine("Deleting " + fileName + " ...");
 				File.Delete(fileName);
+				Log.WriteLine("Deleted");
 				return true;
 			}
-		} catch {}
+		} catch {
+			Log.WriteLine("Problem deleting");
+		}
 		return false;
 	}
 	
@@ -926,6 +952,40 @@ public class Util
 		}
 	}
 
+	//returns int [] of encoder signal or curve
+	//currently used on db conversion 1.05 -> 1.06
+	public static int [] ReadFileAsInts(string fileName)
+	{
+		string contents;
+		try {
+			StreamReader reader = File.OpenText(fileName);
+			contents = reader.ReadToEnd ();
+			reader.Close();
+		} catch {
+			return new int [] {};
+		}
+	
+		//create ints file bigger enought to hold all possible values 	
+		int [] ints = new int [contents.Length];
+		int count = 0;
+		for(int i=0; i < contents.Length; i++) {
+			if(Char.IsDigit(contents[i])) {
+				ints[count] = Convert.ToInt32(contents[i]);
+				if(i > 0 && contents[i-1] == '-')
+					ints[count] *= -1;
+				
+				count ++;
+			}
+		}
+		
+		//create int [] with the needed sized
+		int [] intsCut = new int [count];
+		for(int i=0; i < count; i ++)
+			intsCut[i] = ints[i];
+
+		return intsCut;
+	}
+
 
 	public static void RunRScript(string rScript){
 		//CancelRScript = false;
